@@ -20,7 +20,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
  *
  */
 #include "lwip/debug.h"
@@ -192,9 +192,9 @@ err_t ip_route_list_del(struct ip_addr *addr, struct ip_addr *netmask, struct ip
 	/*LWIP_ASSERT("ip_route_list_del NULL netmask",netmask != NULL);*/
 	if (nexthop==NULL) nexthop=IP_ADDR_ANY;
 	while (*dp != NULL && (
-///         FIX: Use ip_addr_maskcmp() instead of ip_addr_cmp() ??
-///			!ip_addr_cmp(&((*dp)->addr),addr) ||
-			!ip_addr_maskcmp(&((*dp)->addr),addr, netmask) ||
+	/* addr and mask must be compared separately because 
+	 * netmask can be NULL */
+	 		!ip_addr_cmp(&((*dp)->addr),addr) ||
 			(netmask != NULL && !ip_addr_cmp(&((*dp)->netmask),netmask)) ||
 			( !ip_addr_cmp(&((*dp)->nexthop),nexthop) && (*dp)->netif != netif ) 
 			))
